@@ -65,7 +65,7 @@ def check_that_setup_has_not_been_performed(app, reporter):
         filename = os.path.join("default", "app.conf")
         app_conf = app.app_conf()
         if app_conf.has_section("install") and app_conf.has_option(
-            "install", "is_configured"
+                "install", "is_configured"
         ):
             # Sets to either 1 or 0
             is_configured = normalizeBoolean(app_conf.get("install", "is_configured"))
@@ -89,7 +89,13 @@ def check_that_setup_has_not_been_performed(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "self-service", "private_app")
+@splunk_appinspect.tags(
+    "splunk_appinspect",
+    "cloud", "self-service",
+    "private_app",
+    "private_victoria",
+    "private_classic"
+)
 @splunk_appinspect.cert_version(min="2.0.1")
 def check_for_valid_package_id(app, reporter):
     """
@@ -196,42 +202,82 @@ def _is_author_splunk(app_conf):
     return False
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic", "future")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_no_install_source_checksum(app, reporter):
-    """Check in `default/app.conf`, install_source_checksum/install_source_local_checksum not be set explicitly."""
-    stanz_black_list = ["install_source_checksum", "install_source_local_checksum"]
-    if app.file_exists("default", "app.conf"):
-        filename = os.path.join("default", "app.conf")
-        app_conf = app.app_conf()
-        if app_conf.has_section("install"):
-            for stanza in stanz_black_list:
-                if app_conf.has_option("install", stanza):
-                    if app_conf.get("install", stanza):
-                        lineno = (
-                            app_conf.get_section("install").get_option(stanza).lineno
-                        )
-                        reporter_output = (
-                            f"For the app.conf [install] stanza's `{stanza}` attribute,"
-                            " it records a checksum of the tarball from which a given app was installed"
-                            " or a given app's local configuration was installed."
-                            " Splunk Enterprise will automatically populate this value during installation."
-                            " Developers should *not* set this value explicitly within their app!"
-                            f" File: {filename}, Line: {lineno}."
-                        )
-                        reporter.warn(reporter_output, filename, lineno)
-                    else:
-                        pass  # Pass - The property is empty.
-                else:
-                    pass  # Pass - The property does not exist
-        else:
-            pass  # Pass - The stanza does not exist.
-    else:
-        reporter_output = "`default/app.conf` does not exist."
-        reporter.not_applicable(reporter_output)
+    """Check in `default/app.conf` and 'local/app.conf', install_source_checksum not be set explicitly."""
+    file_folder_list = ["default", "local"]
+    stanza = "install_source_checksum"
+    for folder in file_folder_list:
+        if not app.file_exists(folder, "app.conf"):
+            reporter_output = f"`{folder}/app.conf` does not exist."
+            reporter.not_applicable(reporter_output)
+            continue
+
+        filename = os.path.join(folder, "app.conf")
+        app_conf = app.app_conf(folder)
+        if not app_conf.has_section("install"):
+            continue  # Pass - The stanza does not exist.
+
+        if not app_conf.has_option("install", stanza):
+            continue  # Pass - The property does not exist
+
+        if not app_conf.get("install", stanza):
+            continue  # Pass - The property is empty.
+
+        lineno = (
+            app_conf.get_section("install").get_option(stanza).lineno
+        )
+        reporter_output = (
+            f"For the app.conf [install] stanza's `{stanza}` attribute,"
+            " it records a checksum of the tarball from which a given app was installed"
+            " or a given app's local configuration was installed."
+            " Splunk Enterprise will automatically populate this value during installation."
+            " Developers should *not* set this value explicitly within their app!"
+            f" File: {filename}, Line: {lineno}."
+        )
+        reporter.warn(reporter_output, filename, lineno)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic", "future")
+@splunk_appinspect.cert_version(min="1.6.0")
+def check_no_install_source_local_checksum(app, reporter):
+    """Check in `default/app.conf` and 'local/app.conf', install_source_local_checksum not be set explicitly."""
+    stanza = "install_source_local_checksum"
+    file_folder = ["default", "local"]
+    for folder in file_folder:
+        if not app.file_exists(folder, "app.conf"):
+            reporter_output = f"`{folder}/app.conf` does not exist."
+            reporter.not_applicable(reporter_output)
+            continue
+
+        filename = os.path.join(folder, "app.conf")
+        app_conf = app.app_conf(folder)
+
+        if not app_conf.has_section("install"):
+            continue  # Pass - The stanza does not exist.
+
+        if not app_conf.has_option("install", stanza):
+            continue  # Pass - The property does not exist
+
+        if not app_conf.get("install", stanza):
+            continue  # Pass - The property is empty.
+
+        lineno = (
+            app_conf.get_section("install").get_option(stanza).lineno
+        )
+        reporter_output = (
+            f"For the app.conf [install] stanza's `{stanza}` attribute,"
+            " it records a checksum of the tarball from which a given app was installed"
+            " or a given app's local configuration was installed."
+            " Splunk Enterprise will automatically populate this value during installation."
+            " Developers should *not* set this value explicitly within their app!"
+            f" File: {filename}, Line: {lineno}."
+        )
+        reporter.warn(reporter_output, filename, lineno)
+
+
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.7.2")
 def check_for_trigger_stanza(app, reporter):
     """Check that `default/app.conf` doesn't have a `reload.<CONF_FILE>`, where CONF_FILE is
@@ -275,7 +321,7 @@ def check_for_trigger_stanza(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.3.0")
 def check_for_valid_ui_label(app, reporter):
     """Check that the `app.conf` contains a label key value pair in the
@@ -312,7 +358,7 @@ def check_for_valid_ui_label(app, reporter):
         return
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 def check_reload_trigger_for_all_custom_confs(app, reporter):
     """Check that custom conf files have a corresponding reload trigger in app.conf
 
@@ -323,7 +369,7 @@ def check_reload_trigger_for_all_custom_confs(app, reporter):
     # Get all custom confs
     custom_confs = []
     for directory, filename, _ in app.iterate_files(
-        types=[".conf"], basedir=["default", "local"]
+            types=[".conf"], basedir=["default", "local"]
     ):
         if filename not in SPLUNK_DEFINED_CONFS:
             custom_confs.append(filename)
@@ -360,8 +406,8 @@ def _get_conf_permissions(default_meta):
     for section in default_meta.sections():
         name = re.sub(meta_stanza_pattern, "", section.name) or "default"
         is_exported = (
-            section.has_option("export")
-            and section.get_option("export").value == "system"
+                section.has_option("export")
+                and section.get_option("export").value == "system"
         )
         conf_permissions[name] = is_exported
     return conf_permissions
@@ -375,8 +421,8 @@ def _get_reloaded_splunk_confs(settings):
             conf_name = re.sub(reload_pattern, "", setting.name)
             conf_file_name = f"{conf_name}.conf"
             if (
-                conf_file_name in SPLUNK_DEFINED_CONFS
-                and conf_file_name not in splunk_conf_whitelist
+                    conf_file_name in SPLUNK_DEFINED_CONFS
+                    and conf_file_name not in splunk_conf_whitelist
             ):
                 yield conf_name, setting.lineno
 
