@@ -45,7 +45,7 @@ def check_validate_no_duplicate_stanzas_in_conf_files(app, reporter):
                 reporter.fail(reporter_output, key[0], lineno)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.1.12")
 def check_config_file_parsing(app, reporter, included_tags):
     """Check that all config files parse cleanly- no trailing whitespace after
@@ -72,7 +72,7 @@ def check_config_file_parsing(app, reporter, included_tags):
             raise
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.5.0")
 def check_no_default_stanzas(app, reporter):
     """Check that app does not contain any .conf files that create global
@@ -151,7 +151,7 @@ def check_inputs_conf_for_global_settings(app, reporter):
         reporter.not_applicable(reporter_output)
 
 
-@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app")
+@splunk_appinspect.tags("splunk_appinspect", "cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="1.6.0")
 def check_manipulation_outside_of_app_container(app, reporter):
     """Check that app conf files do not point to files outside the app container.
@@ -203,7 +203,7 @@ def check_manipulation_outside_of_app_container(app, reporter):
                         reporter.fail(reporter_output, full_filepath, lineno)
 
 
-@splunk_appinspect.tags("cloud", "private_app")
+@splunk_appinspect.tags("cloud", "private_app", "private_victoria", "private_classic")
 @splunk_appinspect.cert_version(min="2.2.0")
 def check_collections_conf_for_specified_name_field_type(app, reporter):
     """Check that the `filed.<name>` type in collections.conf does not include `boolean`.
